# LiveMCP Claude Skills

Project-specific skills for Ableton Live MCP development.

| Skill | When to use |
|-------|-------------|
| `/verify` | Before every commit — tests, tool count check |
| `/restart-ableton` | After modifying remote script files |
| `/publish` | Publish new version to PyPI |
